/*
 * Copyright (c) 2009-2012, 2012 by cisco Systems, Inc.
 * All rights reserved.
 */


BODY {
	MARGIN: 9px 0px 10px 10px; COLOR: #ff0000; BACKGROUND-COLOR: #f0f0f0
}
FORM {
	MARGIN: 0px
}
LI {
	FONT-FAMILY: Verdana, Helvetica, sans-serif
}
P {
	FONT-FAMILY: Verdana, Helvetica, sans-serif
}
SELECT {
	FONT-FAMILY: Verdana, Helvetica, sans-serif
}
TD {
	FONT-FAMILY: Verdana, Helvetica, sans-serif
}
TH {
	FONT-FAMILY: Verdana, Helvetica, sans-serif
}
EM {
	COLOR: #ff0000; FONT-STYLE: normal
}
H1 {
	FONT-WEIGHT: bold; FONT-SIZE: 16px; MARGIN: 0px 0px 11px; COLOR: #808080; FONT-FAMILY: Arial, Helvetica, sans-serif
}
A {
	COLOR: #1a5e80; TEXT-DECORATION: none
}
A:link {
	COLOR: #1a5e80; TEXT-DECORATION: none
}
A:hover {
	COLOR: #000000; TEXT-DECORATION: underline
}
A:active {
	COLOR: #1a5e80; TEXT-DECORATION: none
}
A.navBar1 {
	COLOR: #1a5e80; TEXT-DECORATION: none
}
A.navBar1:link {
	COLOR: #1a5e80; TEXT-DECORATION: none
}
A.navBar1:hover {
	COLOR: #000000; TEXT-DECORATION: underline
}
A.navBar1:active {
	COLOR: #1a5e80; TEXT-DECORATION: none
}
A.navBar2 {
	COLOR: #666666; TEXT-DECORATION: none
}
A.navBar2:link {
	COLOR: #666666; TEXT-DECORATION: none
}
A.navBar2:hover {
	COLOR: #000000; TEXT-DECORATION: underline
}
A.navBar2:active {
	COLOR: #666666; TEXT-DECORATION: none
}
A.highlight:hover {
	BACKGROUND-COLOR: #ffcc00
}
P.help {
	MARGIN: 13px 0px; WIDTH: 550px
}
SELECT {
	MARGIN-TOP: 1px; MARGIN-BOTTOM: 1px; COLOR: #000000
}
TD.pageTitle {
	FONT-WEIGHT: bold; FONT-SIZE: 14px; PADDING-BOTTOM: 10px; COLOR: #999999
}
TD.horizLine {
	BACKGROUND-COLOR: #cccccc
}
TD.caption {
	PADDING-RIGHT: 0px; PADDING-LEFT: 5px; PADDING-BOTTOM: 6px; COLOR: #666666; PADDING-TOP: 4px
}
TD.level1 {
	FONT-WEIGHT: bold; FONT-SIZE: 12px; COLOR: #1a5e80; PADDING-TOP: 8px
}
TD.level2 {
	PADDING-RIGHT: 0px; PADDING-LEFT: 3px; FONT-WEIGHT: normal; FONT-SIZE: 11px; PADDING-BOTTOM: 0px; WIDTH: 162px; COLOR: #808080; PADDING-TOP: 0px
}
TD.level3 {
	FONT-WEIGHT: normal
}
TD.space {
	FONT-SIZE: 11px; WIDTH: 8px
}
TD.space1 {
	FONT-SIZE: 11px; WIDTH: 11%
}
TD.selected {
	BACKGROUND-COLOR: #ffffff
}
TD.subTitle {
	FONT-WEIGHT: bold; FONT-SIZE: 10pt; COLOR: #666666
}
TD.navBar {
	PADDING-RIGHT: 0px; PADDING-LEFT: 9px; PADDING-BOTTOM: 9px; VERTICAL-ALIGN: top; WIDTH: 165px; PADDING-TOP: 9px; BACKGROUND-COLOR: #d8d8d8
}
TD.noBorder {
	BORDER-RIGHT: #ffffff 0px; BORDER-TOP: #ffffff 0px; BORDER-LEFT: #ffffff 0px; BORDER-BOTTOM: #ffffff 0px
}
TD.checkbox {
	BORDER-BOTTOM: #cccccc 1px solid
}
TD.list {
	PADDING-RIGHT: 5px; PADDING-LEFT: 5px; PADDING-BOTTOM: 0px; PADDING-TOP: 0px; BORDER-BOTTOM: #cccccc 1px solid; HEIGHT: 21px
}
TD.grid {
	BACKGROUND-IMAGE: url(../images/grid20.gif); BORDER-BOTTOM: #999999 1px solid
}
TH {
	PADDING-RIGHT: 5px; PADDING-LEFT: 5px; FONT-WEIGHT: normal; HEIGHT: 21px; BACKGROUND-COLOR: #817e7e
}
A.selected1 {   
	FONT-SIZE: 12px; COLOR: #669999; TEXT-DECORATION: none   
}   
A.selected1:link {   
	FONT-SIZE: 12px; COLOR: #ff0000; TEXT-DECORATION: none   
}   
A.selected1:hover {   
	FONT-SIZE: 12px; COLOR: #669999; TEXT-DECORATION: underline   
}   
A.selected1:active {   
	FONT-SIZE: 12px; COLOR: #669999; TEXT-DECORATION: none   
}   
A.selected2 {   
	COLOR: #1a5e80; TEXT-DECORATION: none   
}   
A.selected2:link {   
	COLOR: #ff0000; TEXT-DECORATION: none   
}   
A.selected2:hover {   
	COLOR: #1a5e80; TEXT-DECORATION: underline   
}   
A.selected2:active {   
	COLOR: #1a5e80; TEXT-DECORATION: none   
} 
