/*
 * Copyright (c) 2009-2012, 2012 by cisco Systems, Inc.
 * All rights reserved.
 */


BODY {
	MARGIN: 10px; BACKGROUND-COLOR: #ffffff
}
A {
	FONT-SIZE: 11px; FONT-FAMILY: Verdana, Helvetica, sans-serif
}
INPUT {
	FONT-SIZE: 11px; FONT-FAMILY: Verdana, Helvetica, sans-serif
}
LI.item {
	FONT-SIZE: 11px; FONT-FAMILY: Verdana, Helvetica, sans-serif
}
P {
	FONT-SIZE: 11px; FONT-FAMILY: Verdana, Helvetica, sans-serif
}
SELECT {
	FONT-SIZE: 11px; FONT-FAMILY: Verdana, Helvetica, sans-serif
}
TD {
	FONT-SIZE: 11px; FONT-FAMILY: Verdana, Helvetica, sans-serif
}
TEXTAREA {
	FONT-SIZE: 11px; FONT-FAMILY: Verdana, Helvetica, sans-serif
}
TEXTAREA.statictextbox {   
    BORDER-RIGHT: 0px; BORDER-TOP: 0px; PADDING-LEFT: 3px; BORDER-LEFT: 0px; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #ffffff; overflow: auto;   
} 
TH {
	FONT-SIZE: 11px; FONT-FAMILY: Verdana, Helvetica, sans-serif
}
H1 {
	FONT-WEIGHT: bold; FONT-SIZE: 16px; MARGIN-BOTTOM: 1px; COLOR: #808080; FONT-FAMILY: Arial, Helvetica, sans-serif
}
H2 {
	FONT-WEIGHT: bold; FONT-SIZE: 14px; MARGIN: 16px 5px 3px 0px; COLOR: #787a7f; FONT-FAMILY: Arial, Helvetica, sans-serif
}
H3 {
	FONT-WEIGHT: bold; FONT-SIZE: 13px; MARGIN: 15px 5px 3px 0px; COLOR: #336699; FONT-FAMILY: Arial, Helvetica, sans-serif
}
INPUT {
	MARGIN: 1px 1px 1px 2px
}
A {
	COLOR: #0066cc; TEXT-DECORATION: underline
}
A:link {
	COLOR: #0066cc; TEXT-DECORATION: underline
}
A:hover {
	COLOR: #ff9100; TEXT-DECORATION: underline
}
A:active {
	COLOR: #0066cc; TEXT-DECORATION: underline
}
A.button {
	FONT-SIZE: 10px; COLOR: #ffffff; FONT-FAMILY: Arial; TEXT-DECORATION: none
}
A.button:link {
	COLOR: #ffffff; TEXT-DECORATION: none
}
A.button:active {
	COLOR: #ffffff; TEXT-DECORATION: none
}
A.button:hover {
	COLOR: #ffcc66; TEXT-DECORATION: none
}
UNKNOWN {
	COLOR: #ffffff; TEXT-DECORATION: none
}
A.sort {
	FONT-WEIGHT: bold; COLOR: #ffcc66
}
A.sort:link {
	COLOR: #ffcc66
}
A.sort:visited {
	COLOR: #ffcc66
}
A.table {
	COLOR: #cc6600; TEXT-DECORATION: underline
}
A.table:link {
	COLOR: #cc6600; TEXT-DECORATION: underline
}
A.table:visited {
	COLOR: #cc6600; TEXT-DECORATION: underline
}
A.highlight:hover {
	BACKGROUND-COLOR: #ffcc00
}
INPUT.button {
	FONT-WEIGHT: bold; WIDTH: 80px; COLOR: #333333; BACKGROUND-COLOR: #c9cbd4
}
INPUT[type="button"]:disabled {
	COLOR:GRAY; BACKGROUND-COLOR: #c9cbd4
}
INPUT.buttonStretch {
	FONT-WEIGHT: bold; COLOR: #333333; BACKGROUND-COLOR: #c9cbd4
}
INPUT.statictextbox {
	BORDER-RIGHT: 0px; BORDER-TOP: 0px; PADDING-LEFT: 3px; BORDER-LEFT: 0px; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #ffffff
}
INPUT.statictextboxlink {
	BORDER-RIGHT: 0px; BORDER-TOP: 0px; PADDING-LEFT: 3px; FONT-WEIGHT: normal; BORDER-LEFT: 0px; CURSOR: pointer; COLOR: #0066cc; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #ffffff; TEXT-DECORATION: underline
}
INPUT.statictextboxlistShaded {
	BORDER-RIGHT: 0px; BORDER-TOP: 0px; PADDING-LEFT: 3px; BORDER-LEFT: 0px; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #cccccc
}
INPUT.statictextboxlist {
	BORDER-RIGHT: 0px; BORDER-TOP: 0px; PADDING-LEFT: 3px; FONT-WEIGHT: normal; BORDER-LEFT: 0px; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #ffffff
}
INPUT.statictextboxlist1 {   
    BORDER-RIGHT: 0px; BORDER-TOP: 0px; PADDING-LEFT: 10px; BORDER-LEFT: 0px; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #ffffff   
}
INPUT.statictextboxlist2 {   
    BORDER-RIGHT: 0px; BORDER-TOP: 0px; PADDING-LEFT: 3px; BORDER-LEFT: 0px; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #eee   
}
INPUT.statictextboxlistDojo {   
    BORDER-RIGHT: 0px; BORDER-TOP: 0px; PADDING-LEFT: 3px; BORDER-LEFT: 0px; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #F0F0F0   
}
INPUT.statictextboxDojo { 
       BORDER-RIGHT: 0px; BORDER-TOP: 0px; PADDING-LEFT: 3px; BORDER-LEFT: 0px; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #F0F0F0; COLOR: #505050; 
} 
INPUT.statictextboxlistright {
	BORDER-RIGHT: 0px; PADDING-RIGHT: 3px; BORDER-TOP: 0px; BORDER-LEFT: 0px; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #ffffff; TEXT-ALIGN: right
}
INPUT.statictextboxlistNoPad {   
    BORDER-RIGHT: 0px; BORDER-TOP: 0px; BORDER-LEFT: 0px; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #eee   
}
INPUT.statictextboxlinkDojo {
	BORDER-RIGHT: 0px; BORDER-TOP: 0px; PADDING-LEFT: 3px; FONT-WEIGHT: normal; BORDER-LEFT: 0px; CURSOR: pointer; COLOR: #0066cc; BORDER-BOTTOM: 0px; BACKGROUND-COLOR: #f0f0f0; TEXT-DECORATION: underline
}
INPUT.statictextboxlabelDojo {
	BORDER-LEFT: 0px; BORDER-RIGHT: 0px; BORDER-TOP: 0px; BORDER-BOTTOM: 0px;FONT-WEIGHT: bold; FONT-SIZE: 13px; COLOR: #1a5e80; BACKGROUND-COLOR: #eee 
}
EM {
	COLOR: #0000ff; font-style: italic; 
}
P.caption {
	FONT-SIZE: 13px; MARGIN: 15px 0px 0px; WIDTH: 350px
}
P.captionSide {
	MARGIN: 4px 0px 7px 8px; WIDTH: 200px
}
PRE {
	FONT-SIZE: 12px; COLOR: #000000
}
SELECT {
	MARGIN: 2px 1px 1px 2px; COLOR: #000000
}
FORM {
	MARGIN: 0px
}
TABLE.banner {
	HEIGHT: 60px; BACKGROUND-COLOR: #0000ff
}
TD.checkbox {
	BORDER-BOTTOM: #cccccc 1px solid
}
TD.content {
	PADDING-RIGHT: 10px; PADDING-LEFT: 10px; PADDING-BOTTOM: 10px; VERTICAL-ALIGN: top; PADDING-TOP: 10px
}
TD.critical {
	PADDING-RIGHT: 5px; PADDING-LEFT: 5px; FONT-WEIGHT: bold; PADDING-BOTTOM: 0px; COLOR: #ffffff; PADDING-TOP: 0px; HEIGHT: 21px; BACKGROUND-COLOR: #ff3333
}
TD.graphLabel {
	FONT-SIZE: 11px; COLOR: #666666; FONT-FAMILY: Tahoma, Arial, Helvetica
}
TD.graphLabel_alt {
	FONT-SIZE: 11px; COLOR: #ff0000; FONT-FAMILY: Tahoma, Arial, Helvetica
}
TD.grid {
	BACKGROUND-IMAGE: url(../images/grid20.gif); BORDER-BOTTOM: #999999 1px solid
}
TD.h2 {
	PADDING-RIGHT: 5px; PADDING-LEFT: 0px; FONT-WEIGHT: bold; FONT-SIZE: 14px; PADDING-BOTTOM: 3px; COLOR: #787a7f; PADDING-TOP: 16px; FONT-FAMILY: Arial, Helvetica, sans-serif
}
TD.horizLine {
	BORDER-TOP: #999fba 1px solid; HEIGHT: 4px
}
TD.label1 {
	PADDING-RIGHT: 5px; PADDING-LEFT: 0px; FONT-WEIGHT: bold; FONT-SIZE: 13px; PADDING-BOTTOM: 0px; COLOR: #1a5e80; PADDING-TOP: 10px; HEIGHT: 38px
}
TD.label1PadTop {   
    PADDING-RIGHT: 5px; PADDING-LEFT: 0px; FONT-WEIGHT: bold; FONT-SIZE: 13px; PADDING-BOTTOM: 0px; COLOR: #1a5e80; PADDING-TOP: 1px; HEIGHT: 38px 
}
TD.label1B {
	FONT-WEIGHT: bold; FONT-SIZE: 13px; COLOR: #336699; HEIGHT: 25px
}
TD.label2 {
	PADDING-RIGHT: 5px; PADDING-LEFT: 16px; PADDING-BOTTOM: 0px; PADDING-TOP: 0px; HEIGHT: 25px
}
TD.label2Top {
	PADDING-RIGHT: 5px; PADDING-LEFT: 16px; PADDING-BOTTOM: 0px; VERTICAL-ALIGN: top; PADDING-TOP: 4px
}
TD.label2PadTop {
	PADDING-RIGHT: 5px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; PADDING-TOP: 11px; HEIGHT: 38px
}
TD.label2B {
	PADDING-RIGHT: 5px; PADDING-LEFT: 0px; FONT-WEIGHT: bold; PADDING-BOTTOM: 0px; COLOR: #1a5e80; PADDING-TOP: 10px; HEIGHT: 38px
}
TD.label2PadBottom {
	PADDING-RIGHT: 5px; PADDING-LEFT: 16px; PADDING-BOTTOM: 5px;  HEIGHT: 25px; 
} 
TD.lineDark {
	BACKGROUND-COLOR: #808080
}
TD.list {
	PADDING-RIGHT: 5px; PADDING-LEFT: 5px; PADDING-BOTTOM: 0px; PADDING-TOP: 0px; BORDER-BOTTOM: #dddddd 1px solid; HEIGHT: 21px; BACKGROUND-COLOR: #ffffff
}
TD.list2 {
	PADDING-RIGHT: 5px; PADDING-LEFT: 5px; PADDING-BOTTOM: 0px; PADDING-TOP: 0px; HEIGHT: 21px
}
TD.listNoPad {
	PADDING-RIGHT: 0px; PADDING-LEFT: 0px; PADDING-BOTTOM: 0px; COLOR: #336666; PADDING-TOP: 0px; BORDER-BOTTOM: #dddddd 1px solid; HEIGHT: 21px
}
TD.pageTitle {
	PADDING-BOTTOM: 20px
}
TD.space {
	WIDTH: 10px; BACKGROUND-COLOR: #cccccc
}
TD.readonly {
	PADDING-RIGHT: 5px; PADDING-LEFT: 5px; PADDING-BOTTOM: 0px; PADDING-TOP: 11px; HEIGHT: 38px
}
TD.subTitle {
	FONT-WEIGHT: bold; FONT-SIZE: 10pt; COLOR: #666666
}
TD.noBorder {
	BORDER-RIGHT: #ffffff 0px; BORDER-TOP: #ffffff 0px; BORDER-LEFT: #ffffff 0px; BORDER-BOTTOM: #ffffff 0px
}
TD.minor {
	PADDING-RIGHT: 5px; PADDING-LEFT: 5px; PADDING-BOTTOM: 0px; PADDING-TOP: 0px; HEIGHT: 21px; BACKGROUND-COLOR: #ffff00
}
TD.tableDisplay {   
    PADDING-TOP: 13px; PADDING-LEFT: 15px;   
}   
TD.list3{   
    PADDING-RIGHT: 0px; PADDING-LEFT: 5px; FONT-WEIGHT: bold; PADDING-BOTTOM: 0px; COLOR: #336666; PADDING-TOP: 0px; BORDER-BOTTOM: #dddddd 1px solid; HEIGHT: 21px   
}   
TD.header {   
    PADDING-RIGHT: 5px; PADDING-LEFT: 5px; FONT-WEIGHT: bold; PADDING-BOTTOM: 4px; COLOR: #336666; PADDING-TOP: 4px; BORDER-BOTTOM: #bbbbbb 1px solid   
}   
TD.headerNoborder {   
    PADDING-RIGHT: 12px; PADDING-LEFT: 0px; FONT-WEIGHT: bold; PADDING-BOTTOM: 0px; COLOR: #336666; PADDING-TOP: 4px; BORDER-BOTTOM: 0px;   
} 
TD.propertyLabel {
	PADDING-RIGHT: 10px; PADDING-LEFT: 0px; FONT-WEIGHT: bold; PADDING-BOTTOM: 0px; COLOR: #2f6681; PADDING-TOP: 0px; FONT-FAMILY: verdana, arial, san-serif; HEIGHT: 26px
}
TD.propertyLabel2 {
	PADDING-RIGHT: 10px; PADDING-LEFT: 20px; PADDING-BOTTOM: 5px; VERTICAL-ALIGN: top; PADDING-TOP: 5px; FONT-FAMILY: verdana, arial, san-serif
}
TD.lineProp {
	BACKGROUND-COLOR: #638fa6
}
TD.list4 {
	PADDING-RIGHT: 5px; PADDING-LEFT: 5px; PADDING-BOTTOM: 0px; PADDING-TOP: 0px; BORDER-BOTTOM: #dddddd 1px solid; BACKGROUND-COLOR: #ffffff
}
TH {
	PADDING-RIGHT: 5px; PADDING-LEFT: 5px; FONT-WEIGHT: bold; PADDING-BOTTOM: 4px; VERTICAL-ALIGN: bottom; COLOR: #1a5e80; PADDING-TOP: 4px; BORDER-BOTTOM: #bbbbbb 1px solid
}
TH.noborder {   
    PADDING-RIGHT: 12px; PADDING-LEFT: 0px; FONT-WEIGHT: bold; PADDING-BOTTOM: 0px; COLOR: #1a5e80; PADDING-TOP: 4px; BORDER-BOTTOM: 0px;   
}   
TH.label1h {   
    PADDING-RIGHT: 4px; PADDING-LEFT: 3px; PADDING-BOTTOM: 0px; PADDING-TOP: 10px; COLOR:black; HEIGHT: 25px; FONT-WEIGHT: normal; BORDER-BOTTOM: 0px;   
} 
TH.label1 {
	PADDING-RIGHT: 5px; PADDING-LEFT: 5px; FONT-WEIGHT: bold; PADDING-BOTTOM: 4px; VERTICAL-ALIGN: bottom; COLOR: #666666; PADDING-TOP: 4px; BORDER-BOTTOM: #bbbbbb 1px solid
}
TR.list {
	BACKGROUND-COLOR: #ffffff
}
DIV.tabcontent {
	PADDING-RIGHT: 10px; PADDING-LEFT: 10px; PADDING-BOTTOM: 10px; PADDING-TOP: 20px
}
SUP {
    font-style:italic; TEXT-DECORATION: underline; COLOR: #0000ff; FONT-SIZE: 9px;FONT-WEIGHT: bold;FONT-FAMILY: Verdana, Helvetica, sans-serif
}
.bigstatictextbox {
    COLOR: #000000;
    BACKGROUND-COLOR: #FFFFFF;
    TEXT-ALIGN: LEFT;
    FONT-SIZE: 11pt;
    FONT-STYLE: normal;
    FONT-WEIGHT: 700;
    BORDER-BOTTOM: #000000 0px inset;
    BORDER-LEFT: #000000 0px outset;
    BORDER-RIGHT: #000000 0px inset;
    BORDER-TOP: #000000 0px outset;
}
.dojoDialog { 
	background : #eee; 
	border : 1px solid #999; 
	-moz-border-radius : 5px; 
	padding : 4px; 
} 
IMG { 
	BORDER-BOTTOM: medium none; BORDER-LEFT: medium none; BORDER-RIGHT: medium none; BORDER-TOP: medium none 
} 

#footNoteDojo {
    position: absolute; left: 20px; margin-top: 0px;
}


#footNote {
    position: absolute; left: 9px; margin-top: 10%;
}
